Adding stub regions
Date: 08 20, 2001 2:26:35 PM

# Adding Stub Concepts

The stub concept is the primary organizer of user-highlighted samples.

To add a stub concept:

1. In the Ana Tab, select the pass in the analyzer sequence where you want the automatically generated rules to be inserted.

2. In the Gram Tab, right click and select Add > Stub.

3. Give the stub concept a name in the dialog box.

4. Click OK to finish adding the stub concept.

Note: The newly added stub concept is added to the analyzer sequence in the Ana Tab as a stub region. The stub region is indicated by stub_name and ends with end_name. You can add a stub region directly to the Ana Tab by highlighting the pass where you want the region to be inserted, right-clicking and selecting Add > Stub from the context menu. The stub concept is added to the Gram Tab.